Coverage report

# Coverage report: 87%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1704 | 219 | 0 | 87%
/home/andrew/Documents/Research/gwent/gwent/__init__.py | 4 | 0 | 0 | 100%
/home/andrew/Documents/Research/gwent/gwent/binary.py | 327 | 44 | 0 | 87%
/home/andrew/Documents/Research/gwent/gwent/detector.py | 629 | 91 | 0 | 86%
/home/andrew/Documents/Research/gwent/gwent/snr.py | 199 | 28 | 0 | 86%
/home/andrew/Documents/Research/gwent/gwent/snrplot.py | 326 | 48 | 0 | 85%
/home/andrew/Documents/Research/gwent/gwent/utils.py | 58 | 6 | 0 | 90%
/home/andrew/Documents/Research/gwent/gwent/waveform.py | 161 | 2 | 0 | 99%

No items found using the specified filter.